@@ -22,16 +22,16 @@ lazy_static! {
 
 async fn gen_client_from_env() -> NamingClient<HttpNamingRemote> {
     use std::env::var;
-    let namespace = var("NACOS.NAMESPACE").unwrap_or(constants::DEFAULT_NAMSPACE.to_owned());
-    let group = var("NACOS.GROUP").unwrap_or(constants::DEFAULT_GROUP.to_owned());
-    let cluster = var("NACOS.CLUSTER").unwrap_or(constants::DEFAULT_CLUSTER.to_owned());
-    let server_schema = var("NACOS.SERVER_SCHEMA").unwrap_or(constants::DEFAULT_SERVER_SCHEMA.to_owned());
-    let server_context = var("NACOS.SERVER_CONTEXT").unwrap_or(constants::DEFAULT_SERVER_CONTEXT.to_owned());
-     let servers = var("NACOS.SERVERS").expect("env NACOS.SERVERS is empty")
+    let namespace = var("NACOS_NAMESPACE").unwrap_or(constants::DEFAULT_NAMSPACE.to_owned());
+    let group = var("NACOS_GROUP").unwrap_or(constants::DEFAULT_GROUP.to_owned());
+    let cluster = var("NACOS_CLUSTER").unwrap_or(constants::DEFAULT_CLUSTER.to_owned());
+    let server_schema = var("NACOS_SERVER_SCHEMA").unwrap_or(constants::DEFAULT_SERVER_SCHEMA.to_owned());
+    let server_context = var("NACOS_SERVER_CONTEXT").unwrap_or(constants::DEFAULT_SERVER_CONTEXT.to_owned());
+     let servers = var("NACOS_SERVER_ADDRS").expect("env NACOS_SERVERS is empty")
         .split(",")
         .map(|server| ServerConfig::new(server_schema.clone(), server.to_string(), server_context.clone()))
         .collect::<Vec<_>>();
-    let failover_dir =var("NACOS.NAMING.FAILOVER").unwrap_or_else(|_|{
+    let failover_dir =var("NACOS_NAMING_FAILOVER").unwrap_or_else(|_|{
         let home = var("HOME").expect("can't obtain home dir");
         format!("{}/{}", home, constants::DEFAULT_FAILOVER_DIR)
     });
@@ -42,10 +42,10 @@ async fn gen_client_from_env() -> NamingClient<HttpNamingRemote> {
         group,
         server_list: servers,
         cache_dir: failover_dir,
-        load_at_start: parse_bool_env("NACOS.NAMING.LOAD_AT_START", false),
-        update_when_empty: parse_bool_env("NACOS.NAMING.LOAD_AT_START", false),
-        user_name: var("NACOS.USERNAME").ok(),
-        password: var("NACOS.PASSWORD").ok(),
+        load_at_start: parse_bool_env("NACOS_NAMING_LOAD_AT_START", false),
+        update_when_empty: parse_bool_env("NACOS_NAMING_LOAD_AT_START", false),
+        user_name: var("NACOS_USERNAME").ok(),
+        password: var("NACOS_PASSWORD").ok(),
     };
     NamingClient::new_http(config).await
 }
